/*
 * (c) Copyright 1993 by Panagiotis Tsirigotis
 * All rights reserved.  The file named COPYRIGHT specifies the terms 
 * and conditions for redistribution.
 */

static char RCSid[] = "$Id: pq.c,v 1.1.1.1 1999/10/12 17:28:59 bbraun Exp $" ;
#include "config.h"
#ifdef PQ_VERSION
static char version[] = PQ_VERSION ;
#endif

int pq_errno ;

